SymbolFlags

Struct SymbolFlags 

pub struct SymbolFlags(/* private fields */);
Symbol flags from TypeScript compiler

Implementations

Source

impl SymbolFlags

pub const NONE: Self

None

pub const FUNCTION_SCOPED_VARIABLE: Self

Variable (var) or parameter

pub const BLOCK_SCOPED_VARIABLE: Self

A block-scoped variable (let or const)

pub const PROPERTY: Self

Property or enum member

pub const ENUM_MEMBER: Self

Enum member

pub const FUNCTION: Self

Function

pub const CLASS: Self

Class

pub const INTERFACE: Self

Interface

pub const CONST_ENUM: Self

Const enum

pub const REGULAR_ENUM: Self

Enum

pub const VALUE_MODULE: Self

Instantiated module

pub const NAMESPACE_MODULE: Self

Uninstantiated module

pub const TYPE_LITERAL: Self

Type Literal or mapped type

pub const OBJECT_LITERAL: Self

Object Literal

pub const METHOD: Self

Method

pub const CONSTRUCTOR: Self

Constructor

pub const GET_ACCESSOR: Self

Get accessor

pub const SET_ACCESSOR: Self

Set accessor

pub const SIGNATURE: Self

Call, construct, or index signature

pub const TYPE_PARAMETER: Self

Type parameter

pub const TYPE_ALIAS: Self

Type alias

pub const EXPORT_VALUE: Self

Exported value marker

pub const ALIAS: Self

An alias for another symbol

pub const PROTOTYPE: Self

Prototype property (no source representation)

pub const EXPORT_STAR: Self

Export * declaration

pub const OPTIONAL: Self

Optional property

pub const TRANSIENT: Self

Transient symbol (created during type check)

pub const ASSIGNMENT: Self

Assignment to property on function acting as declaration

pub const MODULE_EXPORTS: Self

Symbol for CommonJS module of module.exports

pub const CONST_ENUM_ONLY_MODULE: Self

Module contains only const enums or other modules with only const enums

pub const REPLACEABLE_BY_METHOD: Self

Replaceable by method

pub const GLOBAL_LOOKUP: Self

Flag to signal this is a global lookup

pub const ENUM: Self

Enum = RegularEnum | ConstEnum

pub const VARIABLE: Self

Variable = FunctionScopedVariable | BlockScopedVariable

pub const VALUE: Self

Value flags

pub const TYPE: Self

Type flags

pub const NAMESPACE: Self

Namespace flags

pub const MODULE: Self

Module flags

pub const ACCESSOR: Self

Accessor flags

pub const MODULE_MEMBER: Self

Module member flags

pub const EXPORT_HAS_LOCAL: Self

Export has local flags

pub const BLOCK_SCOPED: Self

Block scoped flags

pub const PROPERTY_OR_ACCESSOR: Self

Property or accessor flags

pub const CLASS_MEMBER: Self

Class member flags

pub const EXPORT_SUPPORTS_DEFAULT_MODIFIER: Self

Export supports default modifier

pub const CLASSIFIABLE: Self

Classifiable flags

pub const LATE_BINDING_CONTAINER: Self

Late binding container flags

Source

impl SymbolFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl SymbolFlags

pub const fn iter(&self) -> Iter<SymbolFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<SymbolFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.