pub struct SymbolFlags(/* private fields */);Expand description
Symbol flags from TypeScript compiler
Implementations
Sourceimpl SymbolFlags
impl SymbolFlags
Sourcepub const FUNCTION_SCOPED_VARIABLE: Self
pub const FUNCTION_SCOPED_VARIABLE: Self
Variable (var) or parameter
Sourcepub const BLOCK_SCOPED_VARIABLE: Self
pub const BLOCK_SCOPED_VARIABLE: Self
A block-scoped variable (let or const)
Sourcepub const ENUM_MEMBER: Self
pub const ENUM_MEMBER: Self
Enum member
Sourcepub const CONST_ENUM: Self
pub const CONST_ENUM: Self
Const enum
Sourcepub const REGULAR_ENUM: Self
pub const REGULAR_ENUM: Self
Enum
Sourcepub const VALUE_MODULE: Self
pub const VALUE_MODULE: Self
Instantiated module
Sourcepub const NAMESPACE_MODULE: Self
pub const NAMESPACE_MODULE: Self
Uninstantiated module
Sourcepub const TYPE_LITERAL: Self
pub const TYPE_LITERAL: Self
Type Literal or mapped type
Sourcepub const OBJECT_LITERAL: Self
pub const OBJECT_LITERAL: Self
Object Literal
Sourcepub const CONSTRUCTOR: Self
pub const CONSTRUCTOR: Self
Constructor
Sourcepub const GET_ACCESSOR: Self
pub const GET_ACCESSOR: Self
Get accessor
Sourcepub const SET_ACCESSOR: Self
pub const SET_ACCESSOR: Self
Set accessor
Sourcepub const TYPE_PARAMETER: Self
pub const TYPE_PARAMETER: Self
Type parameter
Sourcepub const TYPE_ALIAS: Self
pub const TYPE_ALIAS: Self
Type alias
Sourcepub const EXPORT_VALUE: Self
pub const EXPORT_VALUE: Self
Exported value marker
Sourcepub const EXPORT_STAR: Self
pub const EXPORT_STAR: Self
Export * declaration
Sourcepub const ASSIGNMENT: Self
pub const ASSIGNMENT: Self
Assignment to property on function acting as declaration
Sourcepub const MODULE_EXPORTS: Self
pub const MODULE_EXPORTS: Self
Symbol for CommonJS module of module.exports
Sourcepub const CONST_ENUM_ONLY_MODULE: Self
pub const CONST_ENUM_ONLY_MODULE: Self
Module contains only const enums or other modules with only const enums
Sourcepub const REPLACEABLE_BY_METHOD: Self
pub const REPLACEABLE_BY_METHOD: Self
Replaceable by method
Sourcepub const GLOBAL_LOOKUP: Self
pub const GLOBAL_LOOKUP: Self
Flag to signal this is a global lookup
Sourcepub const MODULE_MEMBER: Self
pub const MODULE_MEMBER: Self
Module member flags
Sourcepub const EXPORT_HAS_LOCAL: Self
pub const EXPORT_HAS_LOCAL: Self
Export has local flags
Sourcepub const BLOCK_SCOPED: Self
pub const BLOCK_SCOPED: Self
Block scoped flags
Sourcepub const PROPERTY_OR_ACCESSOR: Self
pub const PROPERTY_OR_ACCESSOR: Self
Property or accessor flags
Sourcepub const CLASS_MEMBER: Self
pub const CLASS_MEMBER: Self
Class member flags
Sourcepub const EXPORT_SUPPORTS_DEFAULT_MODIFIER: Self
pub const EXPORT_SUPPORTS_DEFAULT_MODIFIER: Self
Export supports default modifier
Sourcepub const CLASSIFIABLE: Self
pub const CLASSIFIABLE: Self
Classifiable flags
Sourcepub const LATE_BINDING_CONTAINER: Self
pub const LATE_BINDING_CONTAINER: Self
Late binding container flags
Sourceimpl SymbolFlags
impl SymbolFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SymbolFlags
impl SymbolFlags
Sourcepub const fn iter(&self) -> Iter<SymbolFlags>
pub const fn iter(&self) -> Iter<SymbolFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SymbolFlags>
pub const fn iter_names(&self) -> IterNames<SymbolFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.